@@ -1,5 +1,5 @@
 
-# $Id: Ebay.pm,v 2.261 2013-08-20 22:16:03 Martin Exp $
+# $Id: Ebay.pm,v 2.262 2013-08-21 01:15:16 Martin Exp $
 
 =head1 NAME
 
@@ -139,7 +139,7 @@ use WWW::SearchResult 2.072;
 use WWW::Search::Result;
 
 our
-$VERSION = do { my @r = (q$Revision: 2.261 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.262 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 our $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 my $cgi = new CGI;
 
@@ -474,6 +474,7 @@ sub _parse_bids
     $iBids = 0;
     } # if
   $iBids ||= 0;
+  # print STDERR " DDD   setting bid_count to =$iBids=\n";
   $hit->bid_count($iBids);
   return 1;
   } # _parse_bids
@@ -898,6 +899,8 @@ sub _parse_tree
     $hit->title($sTitle);
     $hit->category($iCategory);
     $hit->item_number($iItemNum);
+    # This is just to prevent undef warnings later on:
+    $hit->bid_count(0);
     # The rest of the info about this item is in sister TD elements to
     # the right:
     my @aoSibs = $oTDtitle->right;
